#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xss-sanitize
version:              0.3.7.2
visibility:           public
id:                   xss-sanitize-0.3.7.2-d9Z2UL1Q3oIQ3SIiNACha
key:                  xss-sanitize-0.3.7.2-d9Z2UL1Q3oIQ3SIiNACha
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  34511c46d602220acec9e13c6548bca2
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7.2-d9Z2UL1Q3oIQ3SIiNACha
depends:
    attoparsec-0.14.4-8xTfRBafHfnLSxW1Zd3VTX base-4.18.2.1
    containers-0.6.7 css-text-0.1.3.0-5HfY3gEQogy2ya4gdX1tIn
    network-uri-2.6.4.2-2pvBC2E3r3ZG7itzgqfKfv
    tagsoup-0.14.8-DWOmiJXtEgX7eE3Elrwm1T text-2.0.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

